@@ -3,7 +3,7 @@ function(x,...) {
   if (!inherits(x,"mvna"))
     stop("Argument 'x' must be of class 'mvna'")
   cat("\n")
-  for (i in 1:(length(x)-3)) {
+  for (i in 1:(length(x)-7)) {
     a <- strsplit(names(x)[i]," ")
     q <- round(quantile(1:length(x[[i]]$na)))
     cat("Estimated cumulative hazard for transition",a[[1]][1],"to",a[[1]][2],"\n\n")
@@ -16,7 +16,8 @@ function(x,...) {
     cat("Alternative variance estimates","\n")
     print(round(x[[i]]$var2[q],3),...) ; cat("\n\n\n")
   }
-  if (!(is.na(x$n.cens)))
-    cat("And",x$n.cens,"observations were censored","\n")
+  if (!(is.null(x$cens.name))) {
+    cat(sum(x$ncens),"observations were censored","\n")
+  }
 }
-
+  
